(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     65623,       1856]
NotebookOptionsPosition[     62679,       1761]
NotebookOutlinePosition[     63363,       1784]
CellTagsIndexPosition[     63320,       1781]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Solutions to Sheet 9", "Title"],

Cell[CellGroupData[{

Cell["1. Planck's law", "Subsubsection"],

Cell[TextData[{
 "The only limiting cases are when ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", 
    FractionBox[
     RowBox[{"h", " ", "\[Nu]"}], 
     RowBox[{
      SubscriptBox["k", "B"], "T"}]]}], TraditionalForm]]],
 " is small or large. If ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " is large (low temperature) we write"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"u", "(", 
    RowBox[{"\[Nu]", ",", "T"}], ")"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"8", "\[Pi]", "h", 
        SuperscriptBox["\[Nu]", "3"]}], 
       SuperscriptBox["c", "3"]], 
      FractionBox[
       SuperscriptBox["e", 
        RowBox[{"-", "x"}]], 
       RowBox[{"1", "-", 
        SuperscriptBox["e", 
         RowBox[{"-", "x"}]]}]]}], "\[TildeTilde]", 
     RowBox[{
      FractionBox[
       RowBox[{"8", "\[Pi]", "h", 
        SuperscriptBox["\[Nu]", "3"]}], 
       SuperscriptBox["c", "3"]], 
      SuperscriptBox["e", 
       RowBox[{"-", "x"}]]}]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"4", 
       SuperscriptBox["\[Nu]", "3"]}], 
      SuperscriptBox["c", "3"]], 
     RowBox[{"(", 
      RowBox[{"2", "\[Pi]", " ", "h"}], " ", ")"}], 
     RowBox[{
      RowBox[{"exp", "(", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"h", "/", 
            SubscriptBox["k", "B"]}], ")"}], "\[Nu]"}], "T"]}], ")"}], 
      "."}]}]}]}], TraditionalForm]], "Text"],

Cell[TextData[{
 "Corrections go like powers of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"-", "x"}]], TraditionalForm]]],
 ". For small ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " (large ",
 Cell[BoxData[
  FormBox["T", TraditionalForm]]],
 ") we expand the exponent, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "x"], "\[TildeTilde]", 
    RowBox[{"1", "+", "x"}]}], TraditionalForm]]],
 ", and neglect higher order terms. We find then that"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"u", "(", 
     RowBox[{"\[Nu]", ",", "T"}], ")"}], "\[TildeTilde]", 
    RowBox[{
     FractionBox[
      RowBox[{"8", "\[Pi]", "h", 
       SuperscriptBox["\[Nu]", "3"]}], 
      SuperscriptBox["c", "3"]], 
     FractionBox["1", "x"]}]}], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"8", "\[Pi]", "h", 
       SuperscriptBox["\[Nu]", "3"]}], 
      SuperscriptBox["c", "3"]], 
     FractionBox[
      RowBox[{
       SubscriptBox["k", "B"], "T"}], 
      RowBox[{"h", " ", "\[Nu]"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"8", "\[Pi]", " ", 
       SuperscriptBox["\[Nu]", "2"]}], 
      SuperscriptBox["c", "3"]], 
     SubscriptBox["k", "B"], 
     RowBox[{"T", "."}]}]}]}], TraditionalForm]], "Text"],

Cell[TextData[{
 "Corrections go as powers in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "T"}], TraditionalForm]]],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Lennard-Jones potential", "Subsubsection"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["d", 
      RowBox[{"d", " ", "r"}]], 
     RowBox[{"V", "(", "r", ")"}]}], "=", 
    RowBox[{"-", 
     RowBox[{
      SubscriptBox["V", "0"], "(", 
      RowBox[{
       RowBox[{
        FractionBox["12", "a"], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["a", "r"], ")"}], "13"]}], "-", 
       RowBox[{
        FractionBox["12", "a"], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["a", "r"], ")"}], "7"]}]}], ")"}]}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox["d", "2"], 
      RowBox[{"d", " ", 
       SuperscriptBox["r", "2"]}]], 
     RowBox[{"V", "(", "r", ")"}]}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["V", "0"], "(", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"12", "\[CenterDot]", "13"}], 
         SuperscriptBox["a", "2"]], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["a", "r"], ")"}], "14"]}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"12", "\[CenterDot]", "7"}], 
         SuperscriptBox["a", "2"]], 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["a", "r"], ")"}], "8"]}]}], ")"}], "."}]}]}], 
  TraditionalForm]], "Text"],

Cell[TextData[{
 "(ii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"V", "'"}], 
     RowBox[{"(", "r", ")"}]}], "=", "0"}], TraditionalForm]]],
 " if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "a"}], TraditionalForm]]],
 ". At that point ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"V", "(", "a", ")"}], "=", 
    RowBox[{"-", 
     SubscriptBox["V", "0"]}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"V", "''"}], 
     RowBox[{"(", "a", ")"}]}], "=", 
    RowBox[{"72", " ", 
     FractionBox[
      SubscriptBox["V", "0"], 
      SuperscriptBox["a", "2"]]}]}], TraditionalForm]]],
 ". Thus we find that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"V", "(", "r", ")"}], "=", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["V", "0"]}], "+", 
     RowBox[{"36", " ", 
      FractionBox[
       SubscriptBox["V", "0"], 
       SuperscriptBox["a", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r", "-", "a"}], ")"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"O", "(", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r", "-", "a"}], ")"}], "3"], ")"}], "."}]}]}], 
   TraditionalForm]]],
 " Sketch for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "=", "1"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "0"], "=", "1"}], TraditionalForm]]],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "\"\<PlotLegends`\>\""}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "r"], ")"}], "12"], "-", 
       RowBox[{"2", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "6"]}]}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"36", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r", "-", "1"}], ")"}], "2"]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "0.8", ",", "1.2"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Dashing", "[", 
        RowBox[{"{", "0", "}"}], "]"}], ",", 
       RowBox[{"Dashing", "[", 
        RowBox[{"{", 
         RowBox[{"0.01", ",", "0.01"}], "}"}], "]"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"r", ",", "V"}], "}"}]}], ",", 
    RowBox[{"PlotLegend", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<V(r)\>\"", ",", " ", "\"\<quadratic\>\""}], "}"}]}]}], 
   "]"}], TraditionalForm]], "Input",
 CellChangeTimes->{{3.4771415740329943`*^9, 3.477141576625518*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{}, {}, 
      {Hue[0.67, 0.6, 0.6], Dashing[{0}], LineBox[CompressedData["
1:eJwV1nk4VV0XAHB6VTJkSBJeRZKhVyqkyUIZEsoQEqFBSiEZkwZUQshYUqFZ
pTIlqSXRhCZKFLqXCPeefbiabuLb31/3+T373L33WXuttY/6liCn7RNERER0
REVE/v9rslH9cbfZIGiGBT+6qyeEzheT9KN3DwIv1iakZf53uJnoqbri7iB8
fNueFTORDzPuzVLZPERtGx0ZFcqFku2rVfqNeSCrhTacQ29h4NAHvfcRPDgs
L7gnV1cAswOtapojeSDSvsjCTCofNnhWuLyLor7lVK9+Iw9qTLJjXkdTxyUW
67VmQfbQhtcvDlGzjgMhmYfBfOv7kEfHqVNL1Du3peNpq5b7V3N48CVgdP6c
hLtoJf3Oev89HpiN/dbQHqjD+CPWh1Mq6fPfNeSnr6vH2u/VlYX36X5ioO9e
aT1C51WdhgfUFvK/Zx14iia3YyRVa+j+k1xuHZzyHHUcdV4/fE7HNWLTzik2
oFTWYVfRdh788o6reRnzBt+qLtieMMqD59IC6Bh9j4+setUT//IgrXNrKzPn
AxYFn+tMGuNBMPGs67H9gPF1ku6pInzw+de3M+b0BzTe/c02W4wPJmtlmvwW
tWLegwKDS1J8MDjBtVX3/Yh+HgqjqMoHkey/Ny8VtaMw53f6zxV8YJdOddYe
6kTWukIw1ZQPZpcremIVuvDrzxAXLeCDbMnw+sdLuvCNG2/6BnM+rA/wHO+P
6cLLM7pOl1jyoSUmzSFc7Auuz6k7v8eBD2mcRNHu5C94JTu1qNubD/l5RZb5
GRx0yppb+zqWD5qdzX/D9nejwqDMZG4cH8Sa7qicS+jGD2bCtSPxfHDn+uZX
ZnejB+/Ve6XjfAie91LYWNKNW1ZF9vsm0fH4E1UBA924d+il7EgGH5TcbqYc
d+vBNPtgb6XLfNgmufGnv85XbJr4YNTnGR8iBzdOWnOrF03l+up9nvOhRpAr
JrzXi8Wq01J9XtD9zS71KqztxZTFAeo+DXxQYLwM21p7cb2vipX3az7wVleM
dYn2YUt1dKpXK11PxszN1aUP2/et0PDoo/uTOy4uLujDXs5Da+fJDIzIfHE5
ptSP3vtImb84A2W9gSuJej9+FFPXODiFAe1IJ491ev34cl786DVJBhrVVll/
X9mPt/fY3h2TYWD9PrOEj1v6MfL3B+UiJQaS1TKDRG/0o4QcyxfRZeD5qdHg
CUYDGFeovklRjwH32OStnisHcHSx83O9+XS9TReMii0HkHGtKHTVZ6ByrCt5
qesANucdcLu5iIGWytk5JHwA87SnPHZbzsCuCLOkjooB1DfTyCy2YyD4Ukxb
t8Eguh7POnrXnoHeGd3D9UsGMeaVeESZAwNS491HCkwHsdGTbKxaz9B6BFlL
u0EMiKqe9dSFgUsvT3mY7hjEayWuNzo8GZi92VPk79lBVJ+bVCu1h463yf+s
E+Ghze6xUplAut8t4uodk3gYXLr3snwQA5G8ZyZEioc15u4JSnvp+zvPNhOd
ycPNm+c6aIYxYCbUnNZhwMPcHGxbHsPA5uStg+HePFSQGGF3nWTAxdFfzK6S
h6tbdx+LS2HAb5GVqcojHoZe+qqSl8pA5tSVn7qf8PC9aatV0ykGNIovrvN9
zcPsfVV5C7IZUEqcmCvdy8OZHYdtRs4zoOyzdNcCeT6q3ZHOj7nDgKtkvmr5
dj46xBwzyr5L4+vf8KlyFx8P2Y6/LC6h8bK7FVsRxMcvPez3rjIGts2Ly7kQ
xceCmS1rLe4z4BMabqdzko+acbk/J9UykGhw3VmtlI86rvPWpTUzsCK2pOO6
kI9aL5qeX2yh+TL81KhzjI8aK0It7r1n4I6yh6b0Pwyqajw26myl5+n1652H
JIOyjIfq/M80PnlxreUqDP46mtL/rIfGY0Fm7J7lDD4t/x43/p3uR/Gs6p9w
Bp9o5/2V/8nAhzGFnoT9DNactYjQ+sXAeUX5YrmDDFYdSd1lL2SgcGO6q8JR
Bm/Z6zieHWMg7+Q8l850BjO/eqotmUzAKtT29fFbDG6ZXlcZqETAQcPkjVUX
g1NNb1YEzSQQ6MYJE+cyeN8vsyxYmcDB45+Vn/bQ/VZuuxOiSqB3feZuowEG
H3pMvBY+m8AlV4d9PSMMKuVb5RzUJlAnX6x3bArBJt0XYSkmBMRk37LfFhCM
dL67L3UpgWseuloLFhHUPHBmb9oyAts8bl7Za0hwf9POPekrCEytc0gfNCGo
HSyxPduMQM2HOudSc4Kx5WtdztsQEIrPjMp0Imhi9mpRsTud78bDtpt7CfKY
By11Gwmcbi6acm0fwfxz18M/eRAY1b208EIYQfE/8VXiXnTcKTf0SBTBj+XL
Lbb60vdRdJJXPEIwSu+6o9IuAjaxGRNjUwnqt2cL9AMIfDSU+r3yFEFuQnyW
5W4CUuAk8yOdoG2vd1tIIIFdsljskU1QuUDRtymEwDcVuQk/8ghWKcYHx0YT
uLJDb2XEdYKB9Xvlzxyg65vtyPxRRFAj1LvsdgyBFacvLAm5STDx7bJfnw/R
eImq7t58m+Cm5KFDS+IJKE9LapYoJzgq6p3KSybQmJD1ohwJ3rljt/CfFAKm
fcpSf2oIbvNe1jwzlcCPHJvaFbUEG6unz7A+RWDEziWjvI5gXkTj+YIsAqoO
XZIxLwiu5C8tdj1PvSQvaPs7Gi/HnS0eF+j/o2MtfZsJTqg4LdycT+DR18ea
Hi0Enx/8abWjkEA4Dkxa9YGgk2x5V8QV+n464ylDbQT9FhvInSkm4DHnlPOT
L/T5HO8l524T0JgeVJDGIag3muJVcIfAZ/Mripu4BNk6/vXrJQQM26IP9nXT
83e9YVFVQeO3STKis5dgSpRW6KdHBO7MOF9oxaPPd2zI7UICT4dumvVRO1sc
remuIRCiKj3nKJ+gkmSPFK+WgLj+5weVDMHCvILLo08JvDNbGjTOEhQTfdsg
8pyA1lkv38Qhgju2iwyLvaDxUSeX5YcJztf3NpVuoPk87PKfioDgPVRt/fc1
Afn7zdulvtPz1bT7q/6GgEKgrGos9YGE6Dlab2n+xeYs+k5t4dgepN9M4zXR
93jzDxp/bo44tBLI3HV3PPgXzSfrZ/qrPhLQbJ7x7S31qRs/XKzbaP2Z+Jsa
/CboGrqhYN0nAtr345d/pf4ycdoyny4Cq/+9dsXgD0EZ2eDV3l8ILDP6UhJN
barc5LCZQ6C6Psi5jjpP//hWz24C+62a3RxGCTaY9OzZ1EPgpXTdo1RqoYV5
pMdXApWjljWvqDe6/Ul276P1ff6/M5Z/CSb4uue4fSNwzP36vhjqyoDyAtd+
AsFruEwJteLhoAqXQQJ+p4qbFMcIWiY21jjzaP7rOxpaUodm6jQ48el5p742
30v97lp313pC4BUT6lZLLVpqNrCOpfVz5NKWPmqDh+dGHIYIHB6rUZYYJ+j9
TDhmP0zrI8/uiC51ylu3KfYCAkXVz3NsqB9+KptmN0LPm1fuvY2a91VObe13
ApG9Ge0x1KpsoLbtDwLx6ZwpWdRrhQ2L1vyk9TPpX3Kder+YzkqbXwTa458k
VVMXTT1mbf2bwKQjjpxG6jalbkcrIQHuWYuhdmrxOWaeln8I6F6Re9hLveS/
c36rRwkk55tYsdR+S4TBq/7SfKs2SPlJnWXuFm0xRmC3R0j2KHXd2rKj5uO0
f00N8xmnFhaJ28wWYaHi3G3+/y1nsKTpArXyWA6MUWuXb3eaJcqC2caLbkJq
s2WZreep90laLRmhdsdaT7UJLGy7JOgapA5aPcQ5R322T82ZQ33sxawd//7D
Qlfj0vQW6vMODrw86huHy8/XU1c0H9irKsZC9rYJ+8uom9xv/DhLXSeTNreA
uqejLVplIgsu65oKk6hHt4iLnqV+pqUt2Eet8M34mPIkFsLeSCt5UM/fs10y
l3rk4YC8KfWmiNrpZyazEGtukjZOzzdklM1VEmfh5buY6R3UiUdmzT5NPe/C
tvBK6qqkA7o5U1hIcr73xv//+SJ747aiBAvnRIcbV1L3Z7UZZlOXRQQUyVIr
5RtDliQLXq9uT71D89Fg7vY6BSkWdO1XnT5AbV2UsSaTevXbK+LW1OFlrHOG
NAtbHvldfE/zveV5kf8pGRZ27PPqa6P1wsp+RhVZFo6xSUwqtdRG6RlXqFUX
ZCWuol7dH1RfJcfCziidhItCgmVTjDR6prGgOL3qhRWtzzeOflGBCiwkVmld
66f1zDuT8+YXtb2vsU4itaau8KC0Igsr3WWU634SzLDFT8ZKLPhmzulVof2h
OJ1d9JhaabrelJu0f7xsV09cO5MFbrLn56XUEwLiTXyUWdhfzT/jMELjmbQm
64QqCzKPt+Z70n7l1Njs8Hk2C9cVDe2kaL8LVJh4xU+dBVnNSJNI2g8TPY3/
stSWg4aEQ/tlLe/0jYlz6HnoJtYWDxJcKL1ZfMFcFoYXJfyn309Q1uHb4yM6
dL7BD5H1tB/Pz545U0qXBQm33w1TqW06bYOzqcPGBye40v59OPCW2g09Fn6N
hGt00n7PpoREt/xH15PY4vy+g+Dr16OG8xbReJcdaPZppesPOzhcoy5s1svK
ofdHxfSCHTqLWfg5Nzer8T3tX5ssc/UMab4mpbktpPeNf9/J8QXGLNyKfCLa
+4bGY1ztpckyFlzlJ46O0vvLUN/c29aChRlK8xv6qwjOc8yIbKC2V68tGbhP
+3Xo11N2q+j8smVj/ZUERapO1DmsZmGoaPHz7gqa/5bvdJytaP7EGZvXldB6
9to6ssmWhfqpX+qX0vv5TPLRE3ucWLg6/q5pLIdgWkh76G9q0dyId2X0vk9w
X+Bz1JmFM2c7VXdm0e8bzTbjcy4spOm4JDTS7wPX6vk9ja4sbJzq1HXwJEF5
XrPp/E10P2uyKtJj6fms1RgZ2Erzv0xP+3AAwWgJ3OwfxoL6b+7+Svr94/5E
t3qIml1T81VuCUHjA9kzo8NpvSptFew0IjjM39NyMoKF0oVuf6bT76ldb1Vt
S6NYeFHs99lLj/7/9H6jsRj6vrUBLbf+JWikZSyVeYzm4/JiMVdRgsT81n3M
oflk735BpJ7BhQve5T27x0LA4nSlbhsGkzquisS30/7y+1u7eBkfy8zLeKyQ
hR7hR5/tanwM9A7bXKU8BL5TLn7tiOOhmWnfepOVQ3C+3nfD4feDyHmX2uDn
NQSG4SfGl+oPYq52/9M1h4cg9GD949iwAVQ3jLLtyB+CyMY0NfVn/bjs90Pn
ppohyNzmfHSHSj8GHCrt2Ns9BB79lgWmvt9w14Mu8vSfYZi3Zee4V1kfHqms
jn2jNQyRe/Nf3RH2om6Qw1njNcOQ2SV8dNuqFws/Ka6w3zkM60qftlsUfMWF
U9K8lJKHYUf5QPM424OpPJiceXMYlqeuf3V1XQ8eOnHJeHfjMOxOvChzr6wb
j/Xd7/3FDIPLpkLF3bLd6Pln4ixjGQEMVNTea97PRRee/bSn1LVm3yTMIrlo
35E12VVWALmKYVdvhnHRFOeyYXIC8Evsqj4WzEX1OMvH5dMEcNfs7kZTPy72
ShzdaqQkgO8exOeBIxeDlcWuGaoL4Mr1B2942lz0l7TLq6PetPSX5xYtLvqO
ZqS5aAhgJNJr8cc5XHTqnBMVOkcAsfb3HtWpcdGocJVt2VwBxLUvW1+gwEWh
Thxvsa4A7CQEW/xFuDis3PDlCbX8LY1M7l8ODkpOe++sJ4BCywYZrz8c/Mwv
fLhvPp1feKbX6QcH8W5tSqm+APZfvyVvweNgZaFE3KoF1OFzTz/q5+CdDKeI
Zmr10GX+y/s4WBjG9RYYCMDZy/6bEZeDuX66LnELBVDQ4Xy6tIuDGW4hNtMW
CWB2pXjGwg4OJttUrbhIraYW/PF2Owfjl05YuHixADjGKf76Hzn4PxmcTRc=

        "]]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Dashing[{0.01, 0.01}], 
       LineBox[CompressedData["
1:eJwt2Hk0lVsbAHCVSuKiXEkKiUwZypQrDzJlODdDKEJEI0miojSgQoZMGZNU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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesLabel->{
       FormBox["r", TraditionalForm], 
       FormBox["V", TraditionalForm]},
     AxesOrigin->{0.8, 0},
     DisplayFunction:>$DisplayFunction,
     FormatType->TraditionalForm,
     PlotRange->{{0.8, 1.2}, {-0.9999999658875172, 1.6356675566706338`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
     {GrayLevel[0], 
      RectangleBox[{-1.15, -0.8680339887498949}, \
{-0.3499999999999999, -0.26803398874989476`}]}, 
     {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
      GraphicsGroupBox[{
        RectangleBox[{-1.2, -0.8180339887498949}, \
{-0.3999999999999999, -0.21803398874989477`}], InsetBox[
         GraphicsBox[{{{InsetBox[
              GraphicsBox[
               {Hue[0.9060679774997897, 0.6, 0.6], 
                Dashing[{0.06666666666666667, 0.06666666666666667}], 
                LineBox[{{0, 0}, {1, 0}}]}], {0.08, 0.08}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"quadratic\"\>", {1.2100000000000002`, 0.58}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[
               {Hue[0.67, 0.6, 0.6], Dashing[{0}], 
                LineBox[{{0, 0}, {1, 0}}]}], {0.08, 1.24}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"V(r)\"\>", {1.2100000000000002`, 1.74}, {-1, 0}, 
              Automatic, {1, 0}]}}, {}},
          AspectRatio->0.7500000000000001,
          FormatType->TraditionalForm,
          
          PlotRange->{{-0.1, 3.26}, {-0.1, 
           2.42}}], {-1.2, -0.8180339887498949}, {
         Left, Bottom}, {0.8, 0.6000000000000001}]}]}}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Automatic,
  PlotRange->All]], "Output",
 CellChangeTimes->{3.477141525358322*^9, 3.4771415785466843`*^9, 
  3.477142127125511*^9}]
}, Open  ]],

Cell[TextData[{
 "(iii) Use the formula for  SHM: \[Omega]=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{"72", 
      FractionBox[
       SubscriptBox["V", "0"], 
       SuperscriptBox["a", "2"]], 
      FractionBox["1", "m"]}]], "=", 
    RowBox[{
     FractionBox["6", "a"], 
     SqrtBox[
      RowBox[{"2", 
       FractionBox[
        SubscriptBox["V", "0"], "m"]}]]}]}], TraditionalForm]]],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Practise", "Subsubsection"],

Cell[TextData[{
 "(i) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"f", "(", "0", ")"}], "=", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}]]}], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", 
       FractionBox["1", "2"]}]}], ";", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "''"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          RowBox[{"-", 
           FractionBox["1", "2"]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "/", "2"}]]}], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "''"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", 
       RowBox[{"-", 
        RowBox[{
         FractionBox["1", "4"], "."}]}]}]}]}]}], TraditionalForm]]],
 "\nThus ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{"1", "+", 
     RowBox[{
      FractionBox["1", "2"], "x"}], "-", 
     RowBox[{
      FractionBox["1", "8"], 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"O", "(", 
      SuperscriptBox["x", "3"], ")"}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "(ii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"f", "(", "0", ")"}], "=", "0"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{
          SuperscriptBox["cos", "2"], "(", "x", ")"}]], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", "1"}]}], ";", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "''"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"-", "2"}], 
          RowBox[{
           SuperscriptBox["cos", "3"], "(", "x", ")"}]], 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"sin", "(", "x", ")"}]}], ")"}]}], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "''"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", "0."}]}]}]}], TraditionalForm]]],
 "\nThus ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{"x", "+", 
     RowBox[{"O", "(", 
      SuperscriptBox["x", "3"], ")"}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "(iii)   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"f", "(", "0", ")"}], "=", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "/", "2"}]]}], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", 
       RowBox[{"-", 
        FractionBox["1", "2"]}]}]}], ";", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "''"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{"(", 
          RowBox[{"-", 
           FractionBox["3", "2"]}], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], 
          RowBox[{
           RowBox[{"-", "5"}], "/", "2"}]]}], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "''"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", 
       RowBox[{
        FractionBox["3", "4"], "."}]}]}]}]}], TraditionalForm]]],
 "\nThus ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["1", "2"], "x"}], "+", 
     RowBox[{
      FractionBox["3", "8"], 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"O", "(", 
      SuperscriptBox["x", "3"], ")"}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "(iv) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"f", "(", "0", ")"}], "=", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], 
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}]]}], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", 
       FractionBox["1", "2"]}]}], ";", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "''"}], 
       RowBox[{"(", "x", ")"}]}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"(", 
          FractionBox["3", "2"], ")"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], 
          RowBox[{
           RowBox[{"-", "5"}], "/", "2"}]]}], "\[Implies]", 
        RowBox[{
         RowBox[{"f", "''"}], 
         RowBox[{"(", "0", ")"}]}]}], "=", 
       RowBox[{
        FractionBox["3", "4"], "."}]}]}]}]}], TraditionalForm]]],
 "\nThus ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{"1", "+", 
     RowBox[{
      FractionBox["1", "2"], "x"}], "+", 
     RowBox[{
      FractionBox["3", "8"], 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"O", "(", 
      SuperscriptBox["x", "3"], ")"}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "(v)From ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox[
       RowBox[{
        RowBox[{"sin", "(", "x", ")"}], "=", 
        RowBox[{"x", "-", 
         RowBox[{
          FractionBox["1", "6"], 
          SuperscriptBox["x", "3"]}], "+", 
         FractionBox["1", "120"]}]}],
       TraditionalForm], 
      SuperscriptBox["x", "5"]}], "+"}], "..."}], TraditionalForm]]],
 " we conclude that \nThus ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["1", "6"], 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       FractionBox["1", "120"], 
       SuperscriptBox["x", "4"]}], "+"}], "..."}]}], TraditionalForm]]]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. Full Series", "Subsubsection"],

Cell[TextData[{
 "(i)  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "+", 
       SuperscriptBox["x", "2"]}]], "=", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", 
          SuperscriptBox["x", "2"]}], ")"}], "n"]}], "=", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"], 
        SuperscriptBox["x", 
         RowBox[{"2", "n"}]]}]}]}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "(ii)  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"cosh", "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["e", "x"], "-", 
        SuperscriptBox["e", 
         RowBox[{"-", "x"}]]}], ")"}]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"n", "=", "0"}], "\[Infinity]"], 
         FractionBox[
          SuperscriptBox["x", "n"], 
          RowBox[{"n", "!"}]]}]}], "+", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "x"}], ")"}], "n"], 
        RowBox[{"n", "!"}]]}], "=", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"m", "=", "0"}], "\[Infinity]"], 
        FractionBox[
         SuperscriptBox["x", 
          RowBox[{"2", "m"}]], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "m"}], ")"}], "!"}]]}]}]}]}]}], TraditionalForm]]]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Taylor series and square root", "Subsubsection"],

Cell[TextData[{
 "(i) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{"1", "+", "x"}]], "\[TildeTilde]", 
    RowBox[{"1", "+", 
     RowBox[{
      FractionBox["1", "2"], "x"}], "-", 
     RowBox[{
      FractionBox["1", "8"], 
      SuperscriptBox["x", "2"]}]}]}], TraditionalForm]]],
 ";  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox["10"], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"3", 
       SqrtBox[
        RowBox[{"1", "+", 
         RowBox[{"1", "/", "9"}]}]]}], "\[TildeTilde]", 
      RowBox[{"3", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          FractionBox["1", "2"], 
          FractionBox["1", "9"]}], "-", 
         RowBox[{
          FractionBox["1", "8"], 
          FractionBox["1", "81"]}]}], ")"}]}]}], "=", 
     RowBox[{
      FractionBox["683", "216"], "\[TildeTilde]", "3.16204"}]}]}], 
   TraditionalForm]]],
 ". The \"exact answer\" is ",
 "3.16228."
}], "Text"],

Cell[TextData[{
 "(ii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"143", "=", 
    RowBox[{
     RowBox[{"144", "-", "1"}], "=", 
     RowBox[{
      SuperscriptBox["12", "2"], "-", "1"}]}]}], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{"1", "-", "x"}]], "\[TildeTilde]", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["1", "2"], "x"}], "-", 
     RowBox[{
      FractionBox["1", "8"], 
      SuperscriptBox["x", "2"]}]}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox["143"], "=", 
    RowBox[{
     RowBox[{"12", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"1", "/", "144"}]}]]}], "\[TildeTilde]", 
     RowBox[{"12", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         FractionBox["1", "2"], 
         FractionBox["1", "144"]}], "-", 
        RowBox[{
         FractionBox["1", "8"], 
         FractionBox["1", 
          SuperscriptBox["144", "2"]]}]}], ")"}]}], "\[TildeTilde]", 
     RowBox[{"11.9583", " ", "."}]}]}], TraditionalForm]]],
 "The \"exact answer\" is ",
 Cell[BoxData[
  FormBox["11.958260743101398`", TraditionalForm]], "Output"],
 " as well"
}], "Text"],

Cell[TextData[{
 "(ii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{"1", "-", "x"}]], "\[TildeTilde]", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["1", "2"], "x"}], "-", 
     RowBox[{
      FractionBox["1", "8"], 
      SuperscriptBox["x", "2"]}]}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{"100", "-", "a"}]], "=", 
    RowBox[{
     RowBox[{"10", 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"a", "/", "100"}]}]]}], "\[TildeTilde]", 
     RowBox[{"10", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["1", "2"], 
          FractionBox["a", "100"]}], "-", 
         RowBox[{
          FractionBox["1", "8"], 
          FractionBox[
           SuperscriptBox["a", "2"], 
           SuperscriptBox["100", "2"]]}]}], ")"}], "."}]}]}]}], 
   TraditionalForm]]],
 "The first correction is less than a percent since ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"10", " ", 
     RowBox[{
      SuperscriptBox["a", "3"], "/", 
      SuperscriptBox["100", "3"]}]}], "<", "0.01"}], TraditionalForm]]],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Math Problems", "Subsubsection"],

Cell[TextData[{
 "(i) We use ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"ln", "(", 
     RowBox[{"1", "+", "x"}], ")"}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       SuperscriptBox["x", "n"], "n"], "."}]}]}], TraditionalForm]]],
 " We find that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"ln", "(", 
      RowBox[{"1", "+", "x"}], ")"}], "-", 
     RowBox[{"ln", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox["x", "n"], "n"]}], "-", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "x"}], ")"}], "n"], "n"]}]}]}], TraditionalForm]]],
 ". Terms for even ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " cancel, and we find that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"n", "=", 
     RowBox[{
      RowBox[{"2", "m"}], "+", "1"}]}], ")"}], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"ln", "(", 
     FractionBox[
      RowBox[{"1", "+", "x"}], 
      RowBox[{"1", "-", "x"}]], ")"}], "=", "2"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"m", "=", "0"}], "\[Infinity]"], 
    FractionBox[
     SuperscriptBox["x", 
      RowBox[{
       RowBox[{"2", "m"}], "+", "1"}]], 
     RowBox[{
      RowBox[{"2", "m"}], "+", "1"}]]}], TraditionalForm]]],
 ".\nFor ln(2) we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"ln", "(", "2", ")"}], "=", 
    RowBox[{
     RowBox[{"ln", "(", 
      FractionBox[
       RowBox[{"4", "/", "3"}], 
       RowBox[{"2", "/", "3"}]], ")"}], "\[TildeTilde]", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "3"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}], "3"], "3"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}], "5"], "5"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}], "7"], "7"], "+"}], "..."}], 
       ")"}]}]}]}], TraditionalForm]]],
 ". Calcuating those terms, we find\nln(2)\[TildeTilde]0.693135. The exact \
result is ",
 "0.693147."
}], "Text"],

Cell[TextData[{
 "(ii) Simply use the geometric series, and find\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "x", ")"}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "\[Infinity]"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "k"], 
      SuperscriptBox["x", 
       RowBox[{"k", " ", "n"}]]}]}]}], TraditionalForm]]],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. ", "Subsubsection"],

Cell["(i) Done in class", "Text"],

Cell[TextData[{
 "(ii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["sin", "2"], "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], "-", 
      RowBox[{
       FractionBox["1", "3"], 
       SuperscriptBox["x", "4"]}], "+"}], "..."}]}], TraditionalForm]]],
 ", and thus ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "0", ")"}], "=", "0"}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", "x", "]"}], "2"], "/", "x"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt1Ps31Hkcx3GXlXILi2JdNqREhYrceqMri5iSksZlT2xSym5oneNSFpUN
xdJF2cZtUi5Jcn0zZV12Kpc0GA0zzEdo5puUcMjac/rhdR7/wOs81wSG0Y5L
SUhIHFna/24CjfHFRQo95EPTLxURDJs1SJ6do3CxsssmsZBgWYW50dRnCulR
7PH4AoIW690CyQSF6RvP0iPyCFqpJPSzORTGqbhkHMgl6DA82X6jlMLqtKbt
g1kEaUkvirf4Ubi1b52vbSLByFcJp4IbxGhxR3ZumT/BlIkIzqenYkz26jC6
Tyd4T/aE44UKMV6cDNrkeowgG9zUc4rESFsl+zLFh6B+mXp91zUxXo85vF/C
i+DLtAKFHcFiXJlY5lvmTNCI1lqspixGiqdRs9WC4OvX8uNNASKULE5MeLUo
RJ3GMDUr7fcoxbp2MjZTiJUnn8usfDuOIYf846d0hOifYv6h78IYTloxJw5e
GcGZa9HJCO9QO8qvp//jMDKUeJrZfILbC7WeiOyG8baLeXj3JSEqMioOCc4L
8EJoQJSx8wgmO4bxair5GC19PzJcJMCFZVu+anQNYUDcK8M3RXzUiqgx2zU0
iJn1wuzbIUM4yvamdijysGZwvcIDfR6WlQm0tGe5aKDs4HTwDhe7p+2FZh/7
8NGG5BDBcC/qPuHayTM5ONhc/qOl5RuUUVhddMWrB4WmmRb4pBv9G+NsDDS7
USWGablJshNdK5M7Km51oKklZZo/xcZGWlKsdgQbL+4SdVRHteAOv4dtD7e1
oPrBkrQjq1gYrarXlDXThI+mm1e2Gtbg1YIpyRTFGsznCv8cSyjB3lX7u5nR
JXjMU/sx9+cMDPL00zJZslouuod17jqYx27zMF5ym0BSN/5wKdDfN3VHu5eC
wYfaWRtWNQzkB2ZLPqgGZ0bfC/fDLHhAT71nv50Fu91UpT9XtgCeZCX0nmmB
VD9OnFkVG5KSHx8ts2NDi7uOoodqJ6yOETxgFHeAaI16TNfNblgo91f4d7EL
zv1mEpCq8QZWenwRZ1r3AGdAmRbU2gtjTfpvUtM54H/eblTWlQsKZxz/OV3S
B89MrC4/k+EB8JOa9wq4YLSi7l3eviHYcFvVWL7/LejUndwtk8yHkA6ZzZvL
B0FiTooZLhBA/36Ns3ntQ/DFs57evHYEDikfaHC6ywfuVr8f1iYIIUeTN5oY
IYAz3soq+gME6tLXsT5ZD4Nmxsjh73TeQR/9hmYGfxhKjuYWTkWNQXZi7Rw/
cQS87WP3tdaPg9C2Te+UihDK6af0beYnwDDIPsHishBm5HZKV3uJQOapY5Xx
vBBUxUoZLB8RxB2/5VC+IASTzn5Dtp8IfnX16LBaFAI9K3zP4AkRDH6qkHKS
IvDM4N4lmRgRmPjgI5flBK7aSSrTCkRQzPlqs1GNwNrTqD0xLYL3v6u1WpoQ
oHXaWupki6HawWnU5xABOVv5procMWSnVqi1exNoyuv/yZchhq8P21dsP0LA
LOp8wK0SMTS/47ko+xJQ0qtK0WwWw/dJB9c/CiDQFmoxrP5RDKlzoe61oQQc
lhunKblS0BcgazccT2Dm7IxWiScFC9JhPiYXCZRyW/LdvCkY6HF3CE8goFsa
VJsSSMGa3MjA+UQC8155RO48BbMWkRJSKQSqGHr2sgUUmFq1MroyCZxWpFoK
iino2DVtLZtFwCiygbannIJXyMyyySaQ4XLslz/qKGjNKGTm3CQQPnnzunQ3
BRGrLdZ73SWw4WiILqOXAp29DXOxuQT4z62ZTjwK6mMHM5h/E/DI7m2IH6PA
Nm9cb5ZBYLlUkfMaioL0v/qU9fLJ0o8jXzd+ooBzN7htZwGBiJ49fv5zFKyO
zXIOLiTwrb/wrb/wH6DO+vE=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1, 1}, {-0.7080734100603454, 0.7080734100603454}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.477141525721773*^9, 3.477142127309017*^9}]
}, Open  ]],

Cell[TextData[{
 "(iii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"cos", "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["x", "2"]}], "+"}], "..."}]}], TraditionalForm]]],
 ", and thus ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "0", ")"}], "=", "\[Infinity]"}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "x", "]"}], "/", "x"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", " ", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "5"}], "}"}]}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdjAk0FAgcxkdjzDAZxygJ63zOSaikNkW5UpSpNLJybLTZTh1UorA6WKWi
soQcHahUzl79/xUJwzDGRHIMmZwzjpomaazd773vfe/33u99BsGHmCHzCAQC
a67/rdW6hcOzs2JoPzizxMxDAIe+G134Pi2GLXrCxMXeAnj81MZk6qsY3HVy
CmksAdiaeQYLR8TgVXVk2UyIAFaqxX9gvxeDsVQYOXpOAI79E/W3Holh5PB0
jGGVAJjnGwuXBYjBn9/zcsiyDyI48Qf2vhTBX9L6fNUF/cDjUYdfBY0BtYTn
IzMfAF08pLFSZxQazQcdpx0/Q+mf1SSVrmEIfXvZRfP4EAQm2Yx3xA4B1WwL
pFBHQXr19AVYNwjetEjfnUUiyKV1a90UCOFHrJDuNTAOGR424a0XB0BusrZ/
S9okxO4PijTf+AlmKEblgh1f4DTxQUT4WB/0Gk3tiTomgaCzHGP+PQFY7DtQ
4fdYCqkvBm5mhPXCD6KEH8D4AVU9ZvOLDLuhbgm1xM5dBlFr5IrTF3XDmcZM
+5rtMnC41eF5kdYNEW9c9vkFyQCZly6HTnfBuqCIT7dPyaC2ZkTdgNsFzn5q
2nHFMuAVPtRKO9cF9zezjtRqzIIoYrnp2d6PIIwccT05NAtGqo7rt9/uBAtG
WXIVn4DJ1oJTYdc6gfs8Z3N5NwGlW2Ofnr3QCbb6ZYJKIQHZKdXGxeGd4JOg
UtwsIeAx+kayglsnnPEaS3LRlMO3C5nscvEHsLaZrGT6ymGY7h4fbacPoCD/
7NzSPjl8YnEhrK+/HabSbk28oRBRryWw0rKjHXR9M8Pd1ImYFLGKcrypHVq0
ve9wtYkYUj2cT65shw67tBWEpURctNtTwEhuh0xLomvlDiKeSVFnRdi3gyx4
r05RHhHdpRku8/9+D+fPvxjtdZfHnpoSfTs7PnzbUp5mVUzCqG3fne0ZfLCu
GeQzKki4SOC4b7UhH0K+WkYtf0PCrTOckrU0PnT5d5oFdpAQbUXr3YRtcPtV
1jELBQXMzrIIYaW1wfbFzPC0IAUMPpl7/5SEBznzpNpW+mSUKYw0Ro3O8YaE
6KMMMqZft52M7uPB89/kaNX2ZOQ+erU6rokH61JIXxK8ybhB2NOQWMADuXpK
fmocGY236YgyfHgw0LDJY2CIjAOMVFsoawWtLB/NeqCgRXS+aLCwFWrvDpu9
bqLgQU7pA/WcVug2dabWd1FQeoRvGJrYCtHX/QoVZyioVK5JVw5shcLyeJdN
qxTR2il9apdiK5SGsOePlyni6R1ZzyR+XJB3T8hOBiXEgkeH9b250FD3cldF
sxLKS4Hh4coFlZiKB18FSpic3puXaT3nn2ffKJSnYnaPQaoziQufY4YSKZuo
+HZf3vGrD1vgpSPD5G4nFdWi79tZybWAZU4cJikrY0KZ2TvVb83QsnsoXE9f
GadFd32nRpsh+da1zFpbZewLKIiqaG8GLsVVwmIp4xOn3NfrHzfDbHoqMT5P
GZmkTK+dAc1Au1LnqOdEQ1Mtg0bCaQ6UFOcFZCapoOolvfGaUA60fRw7anNH
BaXTuvREJgdGJLKM3nIVfPdxse8CCw7YJ28mpPSr4B/ZGgPmHU2gZMSR6P2i
ig9MKT+ZK5vgXNH8griTqsiwEzPyp9hwwqutdOJXNQy1iomp7GJDPj93ddlG
NcwyUeE21rJhv8DE7vJONVTXXBoh+YcN5sv8PWOOquG3bwdfuTnP+boSR/8i
NXxdKdoxfL0BFozd8FljqI4sB1H0Urv6ub+uTCV9Ol5dEd2yQb8eTjic+Flt
TceGJTRjllI99Jo4SNKd6Lj2F6u6s911cCWwvyH9dzoazR6gcxPqAD7rDU7c
o2NwJ9WTrFsHhP+jgf8CnGj2MQ==
     "]], LineBox[CompressedData["
1:eJwdkY0/1HkCx8doMjvGeMxim5gu1RXdJKtU9vOtPK+kVnVSE5JaT5WX8nAq
qrXC0WJ74OxqScjDtjbkpiQ6DGJmwoxp3f1mJJH5Fb2sxXJ793693q/3H/AW
hJzad5zJYDBEf/i/shc3jqfxO8D4P2YkvP9Dc46TBB7TEfwma1NSOzZec8Nb
gon0q5euGZmS+QV14T9EEvCTNOfjdUxJ1hppQmmqBLyT3eEZGhNSG1+1sbFf
guNVorv1ZSZk3irsNnWuE0l5IsWikwnJPjqQLKzvQoBL/sAnIcYk9e12jHR1
YVpZEbDf35hcSPjh9wJ1F3A0zrjY3ZhE50Yl6vG6EXlXEJW43pj4tunGDoV2
wzuCt2A6bUR4fxGeyDR5joPbLWO7s4xI1kLa7tGoHkyYlu/KyTckqRla/e8u
96C95Fefs5cNyQULf8kXt3oQq3XfGBdpSKIdrD2aWnvAGl2a1f+ZIVlTe8im
06AXW+v3yOeHeUTv9TvLH0J7MeWml1LrxCNtvnwDPxMprib9ZuSp5RKzDZR5
zHIpsufSbEZUXBJkcMcmb7UU7HB94a0OLpnttHNUbJVCfLOv0eUOl9h5bQ8M
OiaFg63iq6QjXHJtV2D56Z+l8M8+9elPUn1yaMstt28OyLAjKXmpRTuHlH58
ZE9tkAzDXzR6mTVwyNS0TUBfuAz0IcsUQRmHZD4oi7S8KEPowOTh6DQOaXJo
yL19V4ZAJrPzuReHrLIfoO7PyDA6NLQnt+cjMiFYdkGWL0euV/LPSSNssuVv
t880l8iRb1heXKlgk0sv7I//WC1HUOvH428kbGL+tbtP1lM5uBmhDpk1bPLZ
2zgr7zE5bAp646MS2CS7brCu2fkFnM/YLcsxZJONnxfRPypeoLjS4JthVz1y
NnZ9cLZ5P4o2nVUJelnEnEOLDwj6MbfY4yZsZZGG73+yWGHXj52mTjVeDSwy
L3HurdzRj7fnQ1BYxCKXBJ6QRPbj0yulhc/OsEjW81A+q6Uf912fTxuYs0jp
2u+UiacG0PJ+71KLsCVk4KXRvrB2BdL1cyO2CXSJd8ZxRaxMgV8SHzbssNAl
YudG0eWXClRV7ez1NdQlRdePRRS9U6Ai5onL+d+Z5KRf3ZVBCyV6/VcI1w0y
yWxLYL3vl0ocEvPSH+UxyfJ7pcs3cwYhZ036fctjkqCE7a/1fFQYHW64/rWp
DlkX2t6nPaACRUZcw/R1yJSvf2tfsAp/Fy1MeOvqkNRVkbeL41SoC8w3Wz3F
IJU9BYEoViEjuIReKWeQ32znes7NqiCZGKOEeQySI3vY8KrsJQTVfjqnrRik
Zf3m9BbWEBoiq3wCIhew+iPxaInnf2DA/V4cdHYOfHGEGyuNgnCb1/wW7QwY
s8zyGLUaFTpTyc2p0/h17yPRM9thvGrZc2lT+geoHI9+YnvlFWo9ulcNFk7i
9EEj45UvR2CZ1ntPMf4OlnnDf13CH4XXuk1KmxktqgOL7k7Fv0FKddaBw9Zv
cdDlomf7ozG4BfyrorL6De6LolZunR9HeteGBxVxrzHD2aX7cP8E5rjfPrV0
eYV90m1O/JtaNFpdnavfrQFnm36zuFAL5zWeGpGbBs0lg58fLtaiK8x1F9tF
A2F8QnBBtRb2pfwTIXYa8KzrMy2faWHccme5o74GHZEOmmWTWuiPZTn6dKhB
2H++xvOhUU5VvHf3UGPmzIxV9V4aRQXlt7ZCjRpV253dB2l02irzhJvVWFET
9s/MEBqsxODkP61RY35/yQgngcYvI8cMbPXUqC+2dtErpfHvcQfu9TYK0QZ0
W+k9Gkn2OaHVTRRWxz3e536fxpMK5UJ7PYU87yMnvxLTcLw49mFJGYWY9/m5
unIaHq6PO2788WVdYPiKYgUN3QdLzJ4mU6Banct3DtGwP6G8oY2n4HdT8Tjl
DY0tSp6n75cU2MwyLwFNo9kiJCYlmEJTRNyLJx9oNN5YK6sLoHCuz/1o0CyN
yagjYdq9FDbAfGxxkYYiet5+rTeF/wJoUswK
     "]], 
    LineBox[{{-0.0003005541762187743, -5.}, {-0.00029985512901506574`, 5.}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1, 1}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.4771415259401617`*^9, 3.4771421273942738`*^9}]
}, Open  ]],

Cell[TextData[{
 "(iv) Don't need to take limit; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "0", ")"}], "=", "0."}], TraditionalForm]]],
 " Series ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"c", "(", 
       RowBox[{"-", "1"}], ")"}], "n"], 
     SuperscriptBox["x", 
      RowBox[{"n", "+", "1"}]]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    FractionBox["x", 
     RowBox[{"1", "+", "x"}]], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "5"}], "}"}]}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdjHk01Hsfxxm7kSyRikRpEZW1h259e6iuJR4UJYXRcitbuZHlXiFKNyHR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1, 1}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.477141526041033*^9, 3.477142127511292*^9}]
}, Open  ]],

Cell[TextData[{
 "(ii) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["x", 
     RowBox[{"x", "-", 
      RowBox[{
       FractionBox["1", "6"], 
       SuperscriptBox["x", "3"]}]}]], "\[TildeTilde]", 
    RowBox[{"1", "+", 
     RowBox[{
      FractionBox["1", "6"], 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"O", "(", 
      SuperscriptBox["x", "4"], ")"}]}]}], TraditionalForm]]],
 ". Limit is 1."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"x", "/", 
     RowBox[{"Sin", "[", "x", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw12Hk0ldv/B3DzmKkMV2TOPFdKpU9ScisZKhTCTXQRrowRkmSMTMksMiXz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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 1.},
  PlotRange->{{-1, 1}, {1.0000000039490549`, 1.1883950884174939`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.477141526154923*^9, 3.477142127689908*^9}]
}, Open  ]],

Cell[TextData[{
 "(vi) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["e", 
      RowBox[{"\[Beta]", " ", "x"}]], "-", "1"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Beta]", " ", "x"}], "+", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["\[Beta]", "2"], 
       SuperscriptBox["x", "2"]}], "+"}], "..."}]}], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"x", "\[Rule]", "0"}]], 
    RowBox[{"f", "(", "x", ")"}]}], TraditionalForm]]],
 " is infinity."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Plot", "[", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "x"], "-", "1"}]], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "5"}], "}"}]}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwdxQ1YywkcwPFSa7PV2ksnxZ6UKL3IiuUlJFI5eZm36lDSduwu4WhUKhFp
yYVC7yEvoUiocL+frhcvq2WbWnpbdYVJi3D9p3Qv3+f5PF/r0Ai+YJyent7m
f/33mYsnaMbGtDBK1KpqVxMQQUxNInRa8BA932HOJ+D2Xe70oS9aIGsEVTvW
E+Bq7x/a914L1Gc9CpNAAtyZR19Lm7WgNY6L2hZKgGfPx+cXSrQQ3zrJ0WU/
Afzj9TfcgrXA+dpfL8wiQCw7Gv7zHwNwvhRObtEQoFTSNE+2fQDTSI9k1kUd
cDDCzH1yP1iNejuotn6De79Uk0zbNTCNv/CNyGEEQlK4gy0J78B2VMniWI3C
8OnoJFj8Fqram1SRnO9wid5hcb6rDyJGadwQ/hhkr+DuVZzohdZEm/Dq9XqY
8Ou2AzP8/oJ7ReX9k6j6GG1QJN77oRvCdopWvtLo47Z4mW3TtS74HkQ0vGgb
h+mPe89ni9RQs9ZjZKnWALceyIx1F6jBYsJmrt9nA7R3Wx0mD1bDwbLmurWE
AVZeK3ehbFCDF+E3PdzAEDvOSGp/W6wG11lvyfXmhmgn4n5eYaYGjShk++wl
hrjXWZf7KboTsnoDcyszDLGy0974pk0HTE8ax4nzJ2GMh/6tzIkdsPzstBT2
OhIuvNDif4LeAdtnv3x2I4CEyE8+JdS1Q/wtS3yznYR1Ne9Z1vJ2CKQaklKj
SKi8UWyRcbgdRBxCcO4aCQfEs+3i1W1ws95tfSXZCKcyPL3W57ZC5UUuc4HC
CFNndUWJzrQCz6dFsO+1EQ6vSbgbn9QKDRsdJXe7jFCaVm17a28rrCtN3b50
0Aj3sf3IRj6tMPBuzLTIhIy1E/jSB9rXQNnFv3jBj4wiTtjGSUtew5rIjEhe
LRlLHZJE3T0q8F6hTpurpKDVy5AKxxYVGJw49UDXRsEU8TzK/gYVSA55H6vu
paCgWlNIrlBBREr28oi/KThxq3+XU6oKcqoKw20mjcdDaawA8VwVNOvPEVDC
xqPvcLa38clm8M2bF2A1Mh7v5e4/uyGhGaZELlz+nkRFG+9VPbniZpAMvl2M
plT8ljYWzw1thsyCoeOJU6lY7Bj6aKN7MziOGUljf6SiWbCdW0FXE5xTW0e7
51Cxs+bOFB6vCboZFf7WvjSMWUcsm+vUBNzrdN1OPg0ndnnunG/TBA+DTMiP
NtNwzYjsziJ6E/By9CNj9tAQXQe8fPpewaFFj5m7s2iYn+cgCMh4BU7Kmg7n
jzQMPXjpetRXJbj+6fNJcNkYvxu9r4/pV0J55hX3LyXGmHnW9VNstxJ8SuoK
Tz00RnnJk/lHGpTQ1pDn0Sc3xqV9nS8kV5TwzbyAM3mcCdqumzyQvVEJZVf7
t1SEmmCvU7or3FdAentLEM+Zjg6xhQNvbyhAmugYtGMBHXfJ7hWxChSQICyc
VuRHx+E9TTZCiQISpS7JW4R0pD4wZ5uEKCAsyj/yWD4dZy3JHAoarwB+fh+Z
MDfF6A15ZV9/kkNGzc0P5lQG4pWS3VPWyuEyeVGUH4uBhsPgtGK5HHY7nZAd
tWRgaqb6cs4sOZzP87S0cGRgfqd1+jKSHIaEjKmVKxlYu/Py/tPFL+HJfKH9
QBoDmbHXeTP1X8LEB4kt12yZeOy+/VPG343wiDbNK92ZibqBq4FD/Y3AKp4h
SOExsTv4Sky5qhEauSV2Wb5MLF1yqcrrdiN0ztSv9QhnIp+Us2pTcCMkl1h6
XSxnop2Fdb1etAzqyoKkpwJYyEi2GqwRymDlQt/bI6EsHNZx2BK+DGbEjk4W
h7PwaZtl4A8OMghiOevOJrBwR75Z74yWBogrflImvsXCIjvKKN+9AT712eZ/
JLHRiad1KhySwkdJrp6kio3CmXFxFe1SkPScDNHI2Jg33VReXyeF+Zv2zdna
zkaWuYv4a5YUXA4v0h0ZZuPdDFap+e9S0Ps/M/wHhNMEeg==
     "]], 
    LineBox[CompressedData["
1:eJwdzns81PkaB/BZg0HjnpHLuLTinG7KKpE83z3u15BLmW3CuoVqOYQ6akvZ
PYjKdMGWa4O1EbVIo5JqGPdxG0Yjv8FqVvMjFQ3D2n1er8/r88fn/cdjHHrK
N1yGQCBEr+fvptF+RW5BbCD8cxuRo6cG8dPvbKiyj1d7Xq6JskMU57+0s4ES
3hVTfEMT8RIJ46tv2CC5q2xfnKaJou+KmxTk2yA6ItJy+di6xznx+gFtEKh5
gaimu+6vpWH2n9vggY0w6nyuBooe+thyfS8HnCMLfOry1NFD0Z81t9w4sFW/
1+FthjpaWcXu/ELngPkFcafJ/9RRtllfCjOdAxyf8J45+rpPvr+7aYgDV8Nk
zXK2rHvdiOKJ0x0gyFDzfFKvhnKODf+4q6ETqrSDAmx7VFH6rC1Md3bC8CCj
MemRKjqXUiItwDrBP3/8Ij9PFZ3MPXGGpNIFlykBU7rhqsiLTUwQhHVBgbOp
5SmpClIx3xWZpdENe1xZ3K/3qKDs1Z89Z070ADmjRVjwlIzSM8Ub7qb1gGuO
04hTBRmd2+THOZS3vkdrMtWuk9FJC0PnZy97IKc5r20tnIzMHgYZdSj3AsPL
P9ZRlYxIf8zplIT1Qo6Hn5FN5AbE9qIqe2v0QcmF6l7nbUpo484JSrx+H8hW
FJKLdJRQsPI9I4ZpH2gZrTkoKyghScd2S55NH+zxf08xnVJE211tacHf94FD
ANPRs0gRXbWnVf7wqA/ivPPUDukqoqB9eY7XArggPMI+EqCvgJjaRw8+DObC
nOewH1lZAS18NjoyGM2FLj8n1C8loazfK2J1znPB4eBUcu44CT2zaMwtLucC
6dux+NFSEjLZMTxRu8SFowyLwBhzEnpvrHWOm98PS2/MMkU+8mjf2eK4lrJ+
iOjOV+11kEcXB3aEP6juh4+MhJkXVvKI8pOTR/aLfojL+ODUS5VHdrNJum6i
flBKXcz6SSSHcupH61usB+A5tS4mMF0O7XYvwh/wBuAGVhgjfS2LEhO2heRQ
huCww3HvwSgioijhrADjIdAuucUsP0pEjYV1mwy2D0GqY93nS75EtMKx7v3t
2yHYT5lwCLYloovGLsCJHQKyovvELTUiyu4Oo8q1DgHG+rpZ2iSDmP+6O3Lm
1DAcLi0ftdOWQcNjar4RbTw4wpJbfCYiILfMcF4Clwepb+c7z2IExLJuoqeN
8WBK3THKbpSAim5+H1M0x4MNQlr3cDsBRXnXXxrdNAKRKe2JQZUEJGmlNXgd
HwGRNN/59nEC0q9i6lspjcLlQveDF9+sQXCK7R8kDz7MD1NqMzeuwtawtkFx
AB/cfTK7e+RWYcHL7+VgCB/q0iUDhotSSDeJLS5N4oPMf8lhwhEp/NZTQINS
PnQ8bJJZLJTCly3LPaclfJDf1O7ssFMK17mPG6cqxkDmSUKo3qEVaN1mldEq
J4AMwptm6hMJ0M39SudVBXBDbrTsdY0EliziWIa6ArB29KcllUlgu02V+OxO
AdQfNNOeuyIBhovhIctAAbCrd+MHQiQQEU7Sv1chgHmPhmgHRQkoFA7fT3cf
h/pkS1Eb/QuYKrJmylzeQl3DgMlugyWgsmIc5X6egJu0lY9p4k9AkMhUxmMY
nLk9ULc0uQCLPs30V1smgZPQytCDD8C3PKa35dIUJGz+fyijZg5+CFRT3zw2
DXuJc01r1WLQYUwelqXOgH9GmMlcwixU04rKF5Lfwf3Em2vyniIIPHDepa1Z
BAxOfsH0uRmopZ/YbLPyJxRVjHNeTE7DkpI98bH/e/B2WdY46zMFvn3791Jv
i4EUpUekLwtBaf+GFtYdMXxXYof/+kkILWWj7t+VimF6n7meBBfCruSUkIL1
Pxp7f9xROCkEFcOGLJ1XYpjs89WR7RZCe6yFUOuDGBgM8opVsRCQwr+vqnjg
YER9nA2uQliKW9Kt9sHhc6oPlWsvhBo++55nIA4ZqcxXEXZCMKiJeJIVikPd
uxX6zW+EsOJfNq2UgoPu69cMFQMhNJQaHiAxcdDqbtcIXcDgpDLOZlbhoFrb
VK8lxsA06amvUy0Op7YWhnbMYMBwOxp1mYXDqsZsl60Ag/j5/FxiPw7XZEIG
rNox2EqLNijl4bA38VHecisGEy+tK/8jwOGXxyH0lqcYeN/mPb3wDgdZi8wJ
30cYKMhUuBrjOGh+JbpjUIPBs5ikgecfcagcivSfrcTg9KDTsWAJDvv4i/Ks
Mgx2AkW0tobDl4UrtVcKMfgLEGg4tQ==
     "]], 
    LineBox[{{-0.0003005192116041609, -5.}, {-0.00029982016442895825`, 5.}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{-1, 1}, {-5, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.47714152628036*^9, 3.477142127844795*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 948},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home_th", 
   "mccsnrw", "TeX", "Courses", "P201", "Worksheets"}, "Sheet9_sol.ps", 
  CharacterEncoding -> "iso8859-1"]},
Magnification->1.5,
FrontEndVersion->"7.0 for Linux x86 (64-bit) (February 25, 2009)",
StyleDefinitions->"Classic.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 37, 0, 100, "Title"],
Cell[CellGroupData[{
Cell[629, 26, 40, 0, 44, "Subsubsection"],
Cell[672, 28, 357, 13, 55, "Text"],
Cell[1032, 43, 1135, 40, 72, "Text"],
Cell[2170, 85, 510, 19, 70, "Text"],
Cell[2683, 106, 799, 28, 72, "Text"],
Cell[3485, 136, 139, 6, 41, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3661, 147, 51, 0, 44, "Subsubsection"],
Cell[3715, 149, 1331, 48, 134, "Text"],
Cell[5049, 199, 1439, 61, 80, "Text"],
Cell[6491, 262, 82, 2, 54, "Input"],
Cell[CellGroupData[{
Cell[6598, 268, 1205, 37, 121, "Input"],
Cell[7806, 307, 13793, 245, 390, "Output"]
}, Open  ]],
Cell[21614, 555, 434, 18, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22085, 578, 36, 0, 44, "Subsubsection"],
Cell[22124, 580, 1627, 61, 88, "Text"],
Cell[23754, 643, 1229, 46, 82, "Text"],
Cell[24986, 691, 1682, 63, 88, "Text"],
Cell[26671, 756, 1576, 59, 88, "Text"],
Cell[28250, 817, 791, 30, 88, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29078, 852, 39, 0, 44, "Subsubsection"],
Cell[29120, 854, 764, 28, 50, "Text"],
Cell[29887, 884, 1112, 40, 58, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31036, 929, 57, 0, 44, "Subsubsection"],
Cell[31096, 931, 951, 38, 52, "Text"],
Cell[32050, 971, 1196, 46, 82, "Text"],
Cell[33249, 1019, 1173, 46, 85, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34459, 1070, 41, 0, 44, "Subsubsection"],
Cell[34503, 1072, 2627, 95, 291, "Text"],
Cell[37133, 1169, 444, 16, 105, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37614, 1190, 28, 0, 66, "Subsubsection"],
Cell[37645, 1192, 33, 0, 61, "Text"],
Cell[37681, 1194, 447, 18, 50, "Text"],
Cell[CellGroupData[{
Cell[38153, 1216, 282, 10, 56, "Input"],
Cell[38438, 1228, 2343, 44, 350, "Output"]
}, Open  ]],
Cell[40796, 1275, 403, 16, 50, "Text"],
Cell[CellGroupData[{
Cell[41224, 1295, 384, 13, 54, "Input"],
Cell[41611, 1310, 4475, 79, 350, "Output"]
}, Open  ]],
Cell[46101, 1392, 487, 19, 41, "Text"],
Cell[CellGroupData[{
Cell[46613, 1415, 370, 13, 75, "Input"],
Cell[46986, 1430, 3208, 58, 350, "Output"]
}, Open  ]],
Cell[50209, 1491, 434, 17, 59, "Text"],
Cell[CellGroupData[{
Cell[50668, 1512, 254, 9, 54, "Input"],
Cell[50925, 1523, 5883, 102, 368, "Output"]
}, Open  ]],
Cell[56823, 1628, 580, 23, 50, "Text"],
Cell[CellGroupData[{
Cell[57428, 1655, 412, 14, 78, "Input"],
Cell[57843, 1671, 4796, 85, 350, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
